==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/da/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "dette kvt.",
	"field-quarter-short-relative+1": "næste kvt.",
	"field-tue-relative+-1": "sidste tirsdag",
	"field-year": "år",
	"dateFormatItem-Hm": "HH.mm",
	"field-wed-relative+0": "på onsdag",
	"field-wed-relative+1": "næste onsdag",
	"dateFormatItem-ms": "mm.ss",
	"field-minute": "minut",
	"field-month-narrow-relative+-1": "sidste md.",
	"field-tue-narrow-relative+0": "på ti.",
	"field-tue-narrow-relative+1": "næste ti.",
	"field-day-short-relative+-1": "i går",
	"field-thu-short-relative+0": "på tor.",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i forgårs",
	"field-thu-short-relative+1": "næste tor.",
	"field-day-relative+1": "i morgen",
	"field-week-narrow-relative+0": "denne uge",
	"field-day-relative+2": "i overmorgen",
	"field-week-narrow-relative+1": "næste uge",
	"field-wed-narrow-relative+-1": "sidste on.",
	"field-year-narrow": "år",
	"field-year-narrow-relative+0": "i år",
	"field-tue-relative+0": "på tirsdag",
	"field-year-narrow-relative+1": "næste år",
	"field-tue-relative+1": "næste tirsdag",
	"field-second-short": "sek.",
	"dateFormatItem-MMMd": "d. MMM",
	"field-week-relative+0": "denne uge",
	"field-month-relative+0": "denne måned",
	"field-week-relative+1": "næste uge",
	"field-month-relative+1": "næste måned",
	"field-sun-narrow-relative+0": "på sø.",
	"field-mon-short-relative+0": "på man.",
	"field-sun-narrow-relative+1": "næste sø.",
	"field-mon-short-relative+1": "næste man.",
	"field-second-relative+0": "nu",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-month-short": "md.",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-day": "dag",
	"field-year-relative+-1": "sidste år",
	"field-sat-short-relative+-1": "sidste lør.",
	"field-hour-relative+0": "i den kommende time",
	"dateFormatItem-yyyyMEd": "E d/M/y G",
	"field-wed-relative+-1": "sidste onsdag",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "sidste lø.",
	"field-second": "sekund",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-hour-short-relative+0": "denne time",
	"field-quarter": "kvartal",
	"field-week-short": "uge",
	"field-day-narrow-relative+0": "i dag",
	"field-day-narrow-relative+1": "i morgen",
	"field-day-narrow-relative+2": "i overmorgen",
	"field-tue-short-relative+0": "på tir.",
	"field-tue-short-relative+1": "næste tir.",
	"field-month-short-relative+-1": "sidste md.",
	"field-mon-relative+-1": "sidste mandag",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "måned",
	"field-day-narrow": "dag",
	"dateFormatItem-MMM": "MMM",
	"field-minute-short": "min.",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "på lør.",
	"field-sat-short-relative+1": "næste lør.",
	"dateFormat-medium": "d. MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "på mandag",
	"field-mon-relative+1": "næste mandag",
	"field-day-narrow-relative+-1": "i går",
	"field-year-short": "år",
	"field-day-narrow-relative+-2": "i forgårs",
	"field-quarter-relative+-1": "sidste kvartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-week-narrow-relative+-1": "sidste uge",
	"field-sat-relative+-1": "sidste lørdag",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "time",
	"field-minute-narrow-relative+0": "denne minut",
	"dateFormat-full": "EEEE d. MMMM y G",
	"field-month-relative+-1": "sidste måned",
	"dateFormatItem-Hms": "HH.mm.ss",
	"field-quarter-short": "kvt.",
	"field-sat-narrow-relative+0": "på lø.",
	"field-fri-relative+0": "på fredag",
	"field-sat-narrow-relative+1": "næste lø.",
	"field-fri-relative+1": "næste fredag",
	"field-month-narrow-relative+0": "denne md.",
	"field-month-narrow-relative+1": "næste md.",
	"field-sun-short-relative+0": "på søn.",
	"field-sun-short-relative+1": "næste søn.",
	"field-week-relative+-1": "sidste uge",
	"field-quarter-short-relative+-1": "sidste kvt.",
	"field-minute-short-relative+0": "denne minut",
	"field-quarter-relative+0": "dette kvartal",
	"field-minute-relative+0": "i det kommende minut",
	"field-quarter-relative+1": "næste kvartal",
	"field-wed-short-relative+-1": "sidste ons.",
	"dateFormat-short": "d/M/y",
	"field-year-narrow-relative+-1": "sidste år",
	"field-thu-short-relative+-1": "sidste tor.",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"field-mon-narrow-relative+-1": "sidste ma.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "sidste to.",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "sidste ti.",
	"dateFormatItem-H": "HH",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "på ons.",
	"dateFormatItem-M": "M",
	"field-wed-short-relative+1": "næste ons.",
	"field-sun-relative+-1": "sidste søndag",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-d": "d.",
	"field-weekday": "ugedag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "dette kvt.",
	"field-day-short-relative+1": "i morgen",
	"field-sat-relative+0": "på lørdag",
	"field-quarter-narrow-relative+1": "næste kvt.",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "i overmorgen",
	"field-sat-relative+1": "næste lørdag",
	"field-week-short-relative+0": "denne uge",
	"field-week-short-relative+1": "næste uge",
	"field-month-short-relative+0": "denne md.",
	"field-month-short-relative+1": "næste md.",
	"dateFormatItem-MEd": "E d/M",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "på to.",
	"field-sun-narrow-relative+-1": "sidste sø.",
	"field-mon-short-relative+-1": "sidste man.",
	"field-thu-narrow-relative+1": "næste to.",
	"field-thu-relative+0": "på torsdag",
	"field-thu-relative+1": "næste torsdag",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-fri-short-relative+-1": "sidste fre.",
	"field-thu-relative+-1": "sidste torsdag",
	"field-week": "uge",
	"dateFormatItem-Ed": "E 'd'. d.",
	"field-wed-narrow-relative+0": "på on.",
	"field-wed-narrow-relative+1": "næste on.",
	"field-quarter-narrow-relative+-1": "sidste kvt.",
	"field-year-short-relative+0": "i år",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "næste år",
	"field-fri-short-relative+0": "på fre.",
	"field-fri-short-relative+1": "næste fre.",
	"field-week-short-relative+-1": "sidste uge",
	"field-hour-narrow-relative+0": "denne time",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "t.",
	"field-month-narrow": "md.",
	"field-hour-narrow": "t",
	"field-fri-narrow-relative+-1": "sidste fr.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "næste år",
	"field-fri-relative+-1": "sidste fredag",
	"field-tue-short-relative+-1": "sidste tir.",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "på ma.",
	"field-mon-narrow-relative+1": "næste ma.",
	"field-year-short-relative+-1": "sidste år",
	"field-zone": "tidszone",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-quarter-narrow": "kvt.",
	"field-sun-short-relative+-1": "sidste søn.",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i forgårs",
	"field-sun-relative+0": "på søndag",
	"field-sun-relative+1": "næste søndag",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dag",
	"field-week-narrow": "uge",
	"field-era": "æra",
	"field-fri-narrow-relative+0": "på fr.",
	"field-fri-narrow-relative+1": "næste fr."
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/da/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "dette kvt.",
	"field-quarter-short-relative+1": "næste kvt.",
	"field-tue-relative+-1": "sidste tirsdag",
	"field-year": "år",
	"dateFormatItem-Hm": "HH.mm",
	"field-wed-relative+0": "på onsdag",
	"field-wed-relative+1": "på onsdag",
	"dateFormatItem-ms": "mm.ss",
	"field-minute": "minut",
	"field-month-narrow-relative+-1": "sidste md.",
	"field-tue-narrow-relative+0": "på ti.",
	"field-tue-narrow-relative+1": "på ti.",
	"field-day-short-relative+-1": "i går",
	"field-thu-short-relative+0": "på tor.",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "i dag",
	"field-day-short-relative+-2": "i forgårs",
	"field-thu-short-relative+1": "på tor.",
	"field-day-relative+1": "i morgen",
	"field-week-narrow-relative+0": "denne uge",
	"field-day-relative+2": "i overmorgen",
	"field-week-narrow-relative+1": "næste uge",
	"dateFormatItem-EBhms": "E h.mm.ss B",
	"field-wed-narrow-relative+-1": "sidste on.",
	"field-year-narrow": "år",
	"field-era-short": "æra",
	"field-year-narrow-relative+0": "i år",
	"field-tue-relative+0": "på tirsdag",
	"field-year-narrow-relative+1": "næste år",
	"field-tue-relative+1": "på tirsdag",
	"field-weekdayOfMonth": "ugedag i måneden",
	"field-second-short": "sek.",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "ugedag i md.",
	"field-week-relative+0": "denne uge",
	"field-month-relative+0": "denne måned",
	"field-week-relative+1": "næste uge",
	"field-month-relative+1": "næste måned",
	"field-sun-narrow-relative+0": "på sø.",
	"field-mon-short-relative+0": "på man.",
	"field-sun-narrow-relative+1": "på sø.",
	"field-mon-short-relative+1": "på man.",
	"field-second-relative+0": "nu",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "uge i måneden",
	"field-month-short": "md.",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-day": "dag",
	"field-dayOfYear-short": "dag i året",
	"field-year-relative+-1": "sidste år",
	"field-sat-short-relative+-1": "sidste lør.",
	"field-hour-relative+0": "denne time",
	"dateFormatItem-yyyyMEd": "E d/M/y G",
	"field-wed-relative+-1": "sidste onsdag",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "sidste lø.",
	"field-second": "sekund",
	"dateFormatItem-Ehms": "E h.mm.ss a",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-hour-short-relative+0": "denne time",
	"field-quarter": "kvartal",
	"field-week-short": "uge",
	"field-day-narrow-relative+0": "i dag",
	"field-day-narrow-relative+1": "i morgen",
	"field-day-narrow-relative+2": "i overmorgen",
	"field-tue-short-relative+0": "på tir.",
	"field-tue-short-relative+1": "på tir.",
	"field-month-short-relative+-1": "sidste md.",
	"field-mon-relative+-1": "sidste mandag",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "måned",
	"field-day-narrow": "dag",
	"dateFormatItem-MMM": "MMM",
	"field-minute-short": "min.",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "på lør.",
	"field-sat-short-relative+1": "på lør.",
	"dateFormat-medium": "d. MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "på mandag",
	"field-mon-relative+1": "på mandag",
	"field-day-narrow-relative+-1": "i går",
	"field-year-short": "år",
	"field-day-narrow-relative+-2": "i forgårs",
	"field-quarter-relative+-1": "sidste kvartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-dayperiod-narrow": "AM/PM",
	"field-week-narrow-relative+-1": "sidste uge",
	"field-dayOfYear": "dag i året",
	"field-sat-relative+-1": "sidste lørdag",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "time",
	"field-minute-narrow-relative+0": "dette min.",
	"dateFormat-full": "EEEE d. MMMM y G",
	"field-month-relative+-1": "sidste måned",
	"dateFormatItem-Hms": "HH.mm.ss",
	"field-quarter-short": "kvt.",
	"field-sat-narrow-relative+0": "på lø.",
	"field-fri-relative+0": "på fredag",
	"field-sat-narrow-relative+1": "på lø.",
	"field-fri-relative+1": "på fredag",
	"dateFormatItem-EBhm": "E h.mm B",
	"field-month-narrow-relative+0": "denne md.",
	"field-month-narrow-relative+1": "næste md.",
	"field-sun-short-relative+0": "på søn.",
	"field-sun-short-relative+1": "på søn.",
	"field-week-relative+-1": "sidste uge",
	"field-quarter-short-relative+-1": "sidste kvt.",
	"dateFormatItem-Ehm": "E h.mm a",
	"field-minute-short-relative+0": "dette min.",
	"field-quarter-relative+0": "dette kvartal",
	"field-minute-relative+0": "dette minut",
	"field-quarter-relative+1": "næste kvartal",
	"field-wed-short-relative+-1": "sidste ons.",
	"dateFormat-short": "d/M/y",
	"dateFormatItem-Bh": "h B",
	"field-year-narrow-relative+-1": "sidste år",
	"field-thu-short-relative+-1": "sidste tor.",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"field-mon-narrow-relative+-1": "sidste ma.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "sidste to.",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "uge i md.",
	"field-tue-narrow-relative+-1": "sidste ti.",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-M": "M",
	"field-wed-short-relative+0": "på ons.",
	"field-wed-short-relative+1": "på ons.",
	"field-sun-relative+-1": "sidste søndag",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-d": "d.",
	"field-weekday": "ugedag",
	"field-day-short-relative+0": "i dag",
	"field-quarter-narrow-relative+0": "dette kvt.",
	"field-day-short-relative+1": "i morgen",
	"field-sat-relative+0": "på lørdag",
	"field-quarter-narrow-relative+1": "næste kvt.",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "i overmorgen",
	"field-sat-relative+1": "på lørdag",
	"field-week-short-relative+0": "denne uge",
	"field-week-short-relative+1": "næste uge",
	"field-dayOfYear-narrow": "dag i året",
	"field-month-short-relative+0": "denne md.",
	"field-month-short-relative+1": "næste md.",
	"field-weekdayOfMonth-short": "ugedag i md.",
	"dateFormatItem-MEd": "E d/M",
	"field-zone-narrow": "zone",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "på to.",
	"field-sun-narrow-relative+-1": "sidste sø.",
	"field-mon-short-relative+-1": "sidste man.",
	"field-thu-narrow-relative+1": "på to.",
	"field-thu-relative+0": "på torsdag",
	"field-thu-relative+1": "på torsdag",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-fri-short-relative+-1": "sidste fre.",
	"field-thu-relative+-1": "sidste torsdag",
	"field-week": "uge",
	"dateFormatItem-Ed": "E 'd'. d.",
	"field-wed-narrow-relative+0": "på on.",
	"field-wed-narrow-relative+1": "på on.",
	"field-quarter-narrow-relative+-1": "sidste kvt.",
	"field-year-short-relative+0": "i år",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-dayperiod-short": "AM/PM",
	"field-year-short-relative+1": "næste år",
	"field-fri-short-relative+0": "på fre.",
	"field-fri-short-relative+1": "på fre.",
	"field-week-short-relative+-1": "sidste uge",
	"field-hour-narrow-relative+0": "denne time",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "t.",
	"field-zone-short": "zone",
	"field-month-narrow": "md.",
	"field-hour-narrow": "t.",
	"field-fri-narrow-relative+-1": "sidste fr.",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "næste år",
	"field-era-narrow": "æra",
	"field-fri-relative+-1": "sidste fredag",
	"dateFormatItem-Bhms": "h.mm.ss B",
	"field-tue-short-relative+-1": "sidste tir.",
	"field-minute-narrow": "min.",
	"field-mon-narrow-relative+0": "på ma.",
	"dateFormatItem-EHm": "E HH.mm",
	"field-mon-narrow-relative+1": "på ma.",
	"field-year-short-relative+-1": "sidste år",
	"field-zone": "tidszone",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-weekOfMonth-narrow": "uge i md.",
	"dateFormatItem-EHms": "E HH.mm.ss",
	"field-weekday-narrow": "ugedag",
	"field-quarter-narrow": "kvt.",
	"field-sun-short-relative+-1": "sidste søn.",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i forgårs",
	"field-weekday-short": "ugedag",
	"dateFormatItem-Bhm": "h.mm B",
	"field-sun-relative+0": "på søndag",
	"field-sun-relative+1": "på søndag",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dag",
	"field-week-narrow": "uge",
	"field-era": "æra",
	"field-fri-narrow-relative+0": "på fr.",
	"field-fri-narrow-relative+1": "på fr."
}
//end v1.x content
);
